aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrian Dolbec <dolsen@gentoo.org>2013-08-11 08:58:02 -0700
committerBrian Dolbec <dolsen@gentoo.org>2013-08-11 08:59:25 -0700
commit11dd993b67271054cf7a5746e55ebaf41795cfc0 (patch)
treebca9de575a8ece471674e8c09278047998995cb7 /pym/gentoolkit/equery/__init__.py
parentprevent a possible unknown object "cleaner" (diff)
downloadgentoolkit-11dd993b67271054cf7a5746e55ebaf41795cfc0.tar.gz
gentoolkit-11dd993b67271054cf7a5746e55ebaf41795cfc0.tar.bz2
gentoolkit-11dd993b67271054cf7a5746e55ebaf41795cfc0.zip
Add fifo type to equery files, bug 480308.
Diffstat (limited to 'pym/gentoolkit/equery/__init__.py')
-rw-r--r--pym/gentoolkit/equery/__init__.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/pym/gentoolkit/equery/__init__.py b/pym/gentoolkit/equery/__init__.py
index c44de90..7f20103 100644
--- a/pym/gentoolkit/equery/__init__.py
+++ b/pym/gentoolkit/equery/__init__.py
@@ -145,7 +145,7 @@ def format_filetype(path, fdesc, show_type=False, show_md5=False,
@param path: the path
@type fdesc: list
@param fdesc: [file_type, timestamp, MD5 sum/symlink target]
file_type is one of dev, dir, obj, sym.
If file_type is dir, there is no timestamp or MD5 sum.
If file_type is sym, fdesc[2] is the target of the symlink.
@type show_type: bool
@@ -179,6 +179,9 @@ def format_filetype(path, fdesc, show_type=False, show_md5=False,
elif fdesc[0] == "dev":
ftype = "dev"
fpath = path
+ elif fdesc[0] == "fif":
+ ftype = "fifo"
+ fpath = path
else:
sys.stderr.write(
pp.error("%s has unknown type: %s" % (path, fdesc[0]))
@@ -145,7 +145,7 @@ def format_filetype(path, fdesc, show_type=False, show_md5=False,
- file_type is one of dev, dir, obj, sym.
+ file_type is one of dev, dir, obj, sym, fif.
If file_type is dir, there is no timestamp or MD5 sum.
If file_type is sym, fdesc[2] is the target of the symlink.